`psox` is a cross-platform (Linux, MacOS X, etc.) command line utility that can convert various formats of computer audio files in to other formats. It can also apply various effects to these sound files, and, as an added bonus, SoX can play and record audio files on most platforms.

## Usage
```python
import psox
...
```

## Install
`python3 -m pip install psox`

